Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2021-07-23 23:25:48 +0300
committerDavid Crocker <dcrocker@eschertech.com>2021-07-23 23:25:48 +0300
commitb1619bb3707567d948d3e9e362b64398a4810b0e (patch)
tree27aa02ab9bbc315027d0a3a27d84af22173a689b /src/Configuration.h
parentea1d6b17350706d0ffce81a6a8a1e36f6bb61ba6 (diff)
Part way through changing units of stored speeds and accelerations
Diffstat (limited to 'src/Configuration.h')
-rw-r--r--src/Configuration.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/Configuration.h b/src/Configuration.h
index dd67344f..e2ec0db2 100644
--- a/src/Configuration.h
+++ b/src/Configuration.h
@@ -48,7 +48,9 @@ constexpr float DefaultXYInstantDv = 15.0; // mm/sec
constexpr float DefaultZInstantDv = 0.2;
constexpr float DefaultEInstantDv = 2.0;
-constexpr float DefaultMinFeedrate = 0.5; // The minimum movement speed (extruding moves will go slower than this if the extrusion rate demands it)
+constexpr float DefaultMinFeedrate = 0.5; // the default minimum movement speed in mm/sec (extruding moves will go slower than this if the extrusion rate demands it)
+constexpr float AbsoluteMinFeedrate = 0.01; // the absolute minimum movement speed in mm/sec
+constexpr float MinimumJerk = 0.1; // the minimum jerk in mm/sec
constexpr float DefaultAxisMinimum = 0.0;
constexpr float DefaultAxisMaximum = 200.0;